@@ -4,10 +4,10 @@ from .centile_bands import centile_band_for_centile
 from .bmi_functions import bmi_from_height_weight, weight_for_bmi_height
 from .age_advice_strings import comment_prematurity_correction
 from .fictional_child import generate_fictional_child_data
-from .dynamic_growth import correlate_weight, create_correlation_surface, create_thrive_lines
+from .dynamic_growth import create_thrive_line, return_correlation, create_thrive_lines
 from .uk_who import select_reference_data_for_uk_who_chart
 from .turner import select_reference_data_for_turner
 from .trisomy_21 import select_reference_data_for_trisomy_21
 from .measurement import Measurement
-from .chart_functions import create_chart, create_plottable_child_data, generate_custom_centile
+from .chart_functions import create_chart, create_plottable_child_data, generate_custom_centile, generate_custom_sds_line
 from .constants import *
